@@ -1,8 +1,8 @@
-from decimal import Decimal
+NULL_VALUES = ('', '.', None, "None", "null", "NULL")
 
-NULL_VALUES =('','.',None,"None","null")
 
-def get_key_op(key):
+def get_key_op(key:str):
+    """Separate at the key to name and op"""
     if "__" in key:
         cols = key.split("__")
         k = cols[0]
@@ -13,22 +13,24 @@ def get_key_op(key):
     return k, op
 
 
-def convert_value(v,value_type):
+def convert_value(v:str, value_type:type):
+    """Converts str to the data type of the value"""
+    from decimal import Decimal
     if value_type is float:
         return float(v)
     elif value_type is int:
         return int(v)
     elif value_type is bytes:
-        return bytes(v,'ascii')
+        return bytes(v, 'ascii')
     elif value_type is Decimal:
         return Decimal(v)
     return str(v)
 
-def item_match(value, op, qv):
+
+def evaluate(value:type, op:str, qv:type):
+    """Evaluate the current value again the query value based on type."""
     if op == "eq":
         return value == qv
-    elif op == "neq":
-        return value != qv
     elif op == "gt":
         return value > qv
     elif op == "gte":
@@ -39,20 +41,19 @@ def item_match(value, op, qv):
         return value <= qv
     elif op == "in":
         return value in qv
-    elif op == "nin":
-        return value not in qv
     elif op == "contains":
         return qv in value
-    elif op == "ncontains":
-        return qv not in value
     elif op == "icontains":
         return qv.lower() in value.lower()
-    elif op == "nicontains":
-        return qv.lower() not in value.lower()
-    elif op == "null":
+    elif op == "isnull":
         res = value in NULL_VALUES
         return res == qv
 
 
+def check(value:type, op:str, qv:type):
+    """Checks for negation"""
 
-
+    if op.startswith("n"):
+        op = op[1:]
+        return not evaluate(value, op, qv)
+    return evaluate(value, op, qv)
